#!/bin/bash

# sqp_JogglerFeatures.sh v1.13 (3rd January 2013) by Andy Davison
#  Executed by JogglerFeatures applet on sqpOS.

export PATH=$PATH:`dirname $0`
[ ! -e ~/.squeezeplay ] && mkdir ~/.squeezeplay

DEBUG=0

sudo ntpdate ntp2d.mcc.ac.uk &>/dev/null

if [ "$1" = "freespace" ]; then
	BTRFS=`grep -c btrfs /etc/fstab`
	if [ $BTRFS -eq 0 ]; then
		df -h /
	else
		btrfs fi df /
	fi
	exit 0
fi


#### AirPlay

if [ "$1" = "air" ]; then
	
	if [ "$2" = "install" ]; then

		wget http://birdslikewires.co.uk/download/joggler/squeezeplay/os/additional/shairport_sqpos.tgz -O /tmp/shairport_sqpos.tgz  &> ~/.squeezeplay/additional.log
		tar zxvf /tmp/shairport_sqpos.tgz -C /tmp/  &> ~/.squeezeplay/additional.log
		sudo mv /tmp/shairport_sqpos/shairport /usr/local/bin/shairport  &> ~/.squeezeplay/additional.log
		sudo dpkg -i /tmp/shairport_sqpos/deps/* &> ~/.squeezeplay/additional.log
		$0 air enable		

	fi

	## Don't forget: this start/stop routine is also used by squeezeplay.sh at startup.

	if [ "$2" = "enable" ] || [ "$2" = "start" ]; then

		# If we're starting up, check that we actually want to include AirPlay
		if [ "$2" = "start" ]; then
			AIRSTATUS=`cat ~/.squeezeplay/userpath/settings/JogglerFeatures.lua | awk -F\air=\" {'print $2'} | awk -F\" {'print $1'}`
			[ "$AIRSTATUS" = "enabled" ] || exit 0
		fi
	
		# Then we can get on with the business of starting properly.
		$0 air stop
		SQPNAME=`cat ~/.squeezeplay/userpath/settings/Playback.lua | awk -F\name=\" {'print $2'} | awk -F\" {'print $1'}`
		[ $SQPNAME = "" ] && SQPNAME="Unnamed SqueezePlay"
		/usr/local/bin/shairport -a "$SQPNAME" -b 271 -d -q

	fi
	
	if [ "$2" = "disable" ] || [ "$2" = "stop" ]; then

		killall shairport
		sudo service avahi-daemon restart
		sleep 1

	fi
	
	exit 0

fi


#### Logitech Media Server

if [ "$1" = "lms" ]; then

	LMSSERVER="http://downloads.slimdevices.com"
	LMSVERSION="7.7.2"

	if [ "$2" == "help" ]; then
		IP=`sqp_JogglerNetwork.sh ip | awk -F\:\  '{print $2}'`
		echo -n "Logitech Media Server allows you to serve content from this device. After installation, visit http://$IP:9000 with your browser to configure the server software."
		exit 0
	fi

	if [ "$2" = "install" ]; then
		
		wget -P /tmp $LMSSERVER"/LogitechMediaServer_v"$LMSVERSION"/logitechmediaserver_"$LMSVERSION"_all.deb"
		sudo dpkg -i /tmp/logitechmediaserver_"$LMSVERSION"_all.deb &> ~/.squeezeplay/additional.log
		# Strip other architectures
		sleep 2
		find /usr/share/squeezeboxserver/CPAN/arch -maxdepth 2 ! -iname 'i386*' -and -iname '*linux*' -exec sudo rm -rf '{}' \;
		sleep 2
		rm /tmp/logitechmediaserver_"$LMSVERSION"_all.deb
		[ $DEBUG -ne 1 ] && sudo reboot		
		exit 0
	
	fi

	if [ "$2" = "uninstall" ]; then
	
		sudo dpkg --purge logitechmediaserver &> ~/.squeezeplay/additional.log
		sudo rm -rf /var/lib/squeezeboxserver
		sleep 2
		[ $DEBUG -ne 1 ] && sudo reboot		
		exit 0
	
	fi

fi


#### Network Mount Point

if [ "$1" = "nmp" ]; then

	[ ! -d /srv/media ] && sudo mkdir /srv/media

	if [ "$2" = "disable" ]; then
		
		sudo umount -f /srv/media
		cat /etc/fstab | grep -v "/srv/media" > /tmp/fstab.tmp
		sudo mv /tmp/fstab.tmp /etc/fstab
		exit 0
	
	fi

	if [ "$2" = "enable" ]; then
		
		$0 nmp disable
		sleep 1
		
		NMPOPTIONS=`cat ~/.squeezeplay/userpath/settings/JogglerFeatures.lua`
		NMPPROTO=`echo $NMPOPTIONS | awk -F\nmp=\" {'print $2'} | awk -F\" {'print $1'}`
		NMPIP=`echo $NMPOPTIONS | awk -F\nmpip={s=\" {'print $2'} | awk -F\" {'print $1'}`
		NMPPATH=`echo $NMPOPTIONS | awk -F\nmppath={s=\" {'print $2'} | awk -F\" {'print $1'} | sed 's/ /\\\040/g'`

		if [ -n "$NMPPROTO" ] && [ -n "$NMPIP" ] && [ -n "$NMPPATH" ]; then
		
			cp /etc/fstab /tmp/fstab.tmp
		
			if [ "$NMPPROTO" = "smb" ]; then
				
				NMPSMBUSER=`echo $NMPOPTIONS | awk -F\nmpsmbuser=\" {'print $2'} | awk -F\" {'print $1'}`
				NMPSMBPASS=`echo $NMPOPTIONS | awk -F\nmpsmbpass=\" {'print $2'} | awk -F\" {'print $1'}`
				
				if [ -n "$NMPSMBUSER" ] && [ -n "$NMPSMBPASS" ]; then
					echo "//$NMPIP/$NMPPATH   /srv/media   cifs   username=$NMPSMBUSER,password=$NMPSMBPASS,_netdev   0 0" >> /tmp/fstab.tmp
				else
					echo "No username or password specified. Can't apply this CIFS mount point."
				fi
			
			fi

			if [ "$NMPPROTO" = "nfs" ]; then
			
				echo "$NMPIP:$NMPPATH   /srv/media   nfs   defaults,user,auto,noatime,intr   0 0" >> /tmp/fstab.tmp
			
			fi
			
			sudo mv /tmp/fstab.tmp /etc/fstab
			sleep 1
			sudo mount /srv/media
		
		fi
		
		exit 0
	
	fi

fi


#### SSH

if [ "$1" = "ssh" ]; then

	if [ "$2" = "install" ]; then
		
		sudo dpkg -i /opt/squeezeplay/config/sqpos/packages/ssh/* &> ~/.squeezeplay/additional.log
		exit 0
	
	fi

	if [ "$2" = "uninstall" ]; then
	
		sudo dpkg --purge ssh openssh-server &> ~/.squeezeplay/additional.log
		sleep 2
		[ $DEBUG -ne 1 ] && sudo reboot		
		exit 0
	
	fi

fi


