
--[[
=head1 NAME

applets.JogglerFeatures.JogglerFeaturesApplet

=head1 DESCRIPTION

JogglerFeatures v1.06 (19th October 2012)

This applet is used to install or remove software on the O2 Joggler.

=cut
--]]


-- Things we might be using.
local setmetatable, tonumber, tostring = setmetatable, tonumber, tostring

local os                     = require("os")
local io                     = require("io")
local oo                     = require("loop.simple")
local math                   = require("math")
local string                 = require("string")
local table                  = require("jive.utils.table")
local debug                  = require("jive.utils.debug")

local Applet                 = require("jive.Applet")
local System                 = require("jive.System")
local Checkbox               = require("jive.ui.Checkbox")
local Choice                 = require("jive.ui.Choice")
local Framework              = require("jive.ui.Framework")
local Event                  = require("jive.ui.Event")
local Icon                   = require("jive.ui.Icon")
local Label                  = require("jive.ui.Label")
local Button                 = require("jive.ui.Button")
local Popup                  = require("jive.ui.Popup")
local Group                  = require("jive.ui.Group")
local RadioButton            = require("jive.ui.RadioButton")
local RadioGroup             = require("jive.ui.RadioGroup")
local SimpleMenu             = require("jive.ui.SimpleMenu")
local Slider                 = require("jive.ui.Slider")
local Surface                = require("jive.ui.Surface")
local Textarea               = require("jive.ui.Textarea")
local Textinput              = require("jive.ui.Textinput")
local Window                 = require("jive.ui.Window")
local ContextMenuWindow      = require("jive.ui.ContextMenuWindow")
local Timer                  = require("jive.ui.Timer")
local Keyboard               = require("jive.ui.Keyboard")

local appletManager = appletManager
local jiveMain		= jiveMain

module(..., Framework.constants)
oo.class(_M, Applet)


-- Define the initial menu.
function menu(self, menuItem)

	osver = os.capture('sqp_JogglerUpdate.sh oschk')
	osreq = 105

	local window = Window("text_list", self:string("TITLE"))
	local textarea = Textarea("help_text", self:string("INSTALLWARN"))

	if tonumber(osver) >= osreq then
		
		log:info("okay")

		local menu = SimpleMenu("menu", {

			{
				text = self:string("AIR"),
				sound = "WINDOWSHOW",
				callback = function(event, menuItem)
					self:installair(menuItem)
				end
			},

			{
				text = self:string("LMS"),
				sound = "WINDOWSHOW",
				callback = function(event, menuItem)
					self:installlms(menuItem)
				end
			},
			
			{
				text = self:string("NMP"),
				sound = "WINDOWSHOW",
				callback = function(event, menuItem)
					self:enablenmp(menuItem)
				end
			},
	
			{
				text = self:string("SSH"),
				sound = "WINDOWSHOW",
				callback = function(event, menuItem)
					self:installssh(menuItem)
				end
			},
	
			{
				text = self:string(" "),
				style = 'item_choice',
				callback = function(event, menuItem)
				
				end
			},
	
			{
				text = self:string("INSLOG"),
				sound = "WINDOWSHOW",
				callback = function(event, menuItem)
					self:inslog(menuItem)
				end
			},
		
			{
				text = self:string("FREE"),
				sound = "WINDOWSHOW",
				callback = function(event, menuItem)
					self:freediskspace(menuItem)
				end
			},
		
		})
		
		window:addWidget(menu)
		menu:setHeaderWidget(textarea)
		self:tieAndShowWindow(window)
		return window
		
	else
	
		log:info("SqueezePlay OS is older than v" .. osreq .. ". Some features unavailable.")
	
		local menu = SimpleMenu("menu", {

				{
					text = self:string("SSH"),
					sound = "WINDOWSHOW",
					callback = function(event, menuItem)
						self:installssh(menuItem)
					end
				},
	
				{
					text = self:string("INSLOG"),
					sound = "WINDOWSHOW",
					callback = function(event, menuItem)
						self:inslog(menuItem)
					end
				},
	
		})
	
		window:addWidget(menu)
		menu:setHeaderWidget(textarea)
		self:tieAndShowWindow(window)
		return window
		
	end
	
end


-- Define the free disk space screen
function freediskspace(self)
	local window = Window("text_list", self:string("FREE"))
	--window:setAllowScreensaver(false)
	freespace = os.capture("sqp_JogglerFeatures.sh freespace")
	local textarea = Textarea("text", freespace)
	window:addWidget(textarea)
	self:tieAndShowWindow(window)
end


-- Define the installation log screen
function inslog(self)
	local window = Window("text_list", self:string("INSLOG"))
	--window:setAllowScreensaver(false)
	ilog = os.capture("cat ~/.squeezeplay/additional.log")
	local textarea = Textarea("text", ilog)
	window:addWidget(textarea)
	self:tieAndShowWindow(window)
end


-- Define the AIR submenu
function installair(self, menuItem)
	local window = Window("text_list", menuItem.text)
	local textarea = Textarea("help_text", self:string("AIRINFO"))
	
	local air = self:getSettings()["air"]

	local group = RadioGroup()
	
	local menu = SimpleMenu("menu", {
		{
			text = self:string("AIRINSTALL"),
			style = 'item_choice',
			sound = "WINDOWSHOW",
			callback = function(event, menuItem)
				self:popupmsg('AIRINSTALLING',5000)
				os.execute("sqp_JogglerFeatures.sh air install &")
				self:getSettings()["air"] = "enabled"
				self:storeSettings()
			end
		},
		{
			text = self:string("AIRENABLE"),
			style = 'item_choice',
			check = RadioButton(
				"radio", group,
				function(event, menuItem, statusfile)
					os.execute("sqp_JogglerFeatures.sh air enable &")
					self:getSettings()["air"] = "enabled"
					self:storeSettings()
					self:popupmsg('AIRENABLEDMSG',5000)
				end,
			air == "enabled")
		},
		{
			text = self:string("AIRDISABLE"),
			style = 'item_choice',
			check = RadioButton(
				"radio", group,
				function(event, menuItem)
					os.execute("sqp_JogglerFeatures.sh air disable &")
					self:getSettings()["air"] = "disabled"
					self:storeSettings()
					self:popupmsg('AIRDISABLEDMSG',5000)
				end,
			air == "disabled")
		},
	})

	window:addWidget(menu)
	menu:setHeaderWidget(textarea)
	self:tieAndShowWindow(window)
	return window;
end


-- Define the NMP submenu
function enablenmp(self, menuItem)
	local window = Window("text_list", menuItem.text)
	local textarea = Textarea("help_text", self:string("NMPINFO"))
	
	local nmp = self:getSettings()["nmp"]

	local group = RadioGroup()
	
	local menu = SimpleMenu("menu", {
	
		{
			text = self:string("NMPDISABLE"),
			style = 'item_choice',
			check = RadioButton(
				"radio", group,
				function(event, menuItem)
					self:getSettings()["nmp"] = "disabled"
					self:getSettings()["nmpip"] = ""
					self:getSettings()["nmppath"] = ""
					self:getSettings()["nmpsmbuser"] = ""
					self:getSettings()["nmpsmbpass"] = ""
					self:popupmsg('NMPDISABLED',5000)
					os.execute("sqp_JogglerFeatures.sh nmp disable &")
					self:storeSettings()
				end,
			nmp == "disabled")
		},
		{
			text = self:string("NMPNFS"),
			style = 'item_choice',
			check = RadioButton(
				"radio", group,
				function(event, menuItem)
					self:getSettings()["nmp"] = "nfs"
					self:storeSettings()
				end,
			nmp == "nfs")
		},
		{
			text = self:string("NMPSMB"),
			sound = "WINDOWSHOW",
			callback = function(event, menuItem)
				self:getSettings()["nmp"] = "smb"
				self:storeSettings()
				self:enablenmpsmb(menuItem)
			end
		},
		{
			text = self:string("NMPIP"),
			sound = "WINDOWSHOW",
			callback = function(event, menuItem)
				self:keyboardWindow(menuItem, 'ip', Textinput.textValue("", 7, 15), "nmpip")					
			end
		},
		{
			text = self:string("NMPPATH"),
			sound = "WINDOWSHOW",
			callback = function(event, menuItem)
				self:keyboardWindow(menuItem, 'qwerty', Textinput.textValue("", 1, 999), "nmppath")					
			end
		},
		{
			text = self:string("NMPAPPLY"),
			style = 'item_choice',
			sound = "WINDOWSHOW",
			callback = function(event, menuItem)
				self:popupmsg('NMPAPPLIED',5000)
				os.execute("sqp_JogglerFeatures.sh nmp enable &")
				self:storeSettings()
			end
		},
	})

	window:addWidget(menu)
	menu:setHeaderWidget(textarea)
	self:tieAndShowWindow(window)
	return window;
end


-- Define the NMP submenu SMB submenu!
function enablenmpsmb(self, menuItem)
	local window = Window("text_list", menuItem.text)
	local textarea = Textarea("help_text", self:string("NMPSMBINFO"))
	
	local nmp = self:getSettings()["nmp"]

	local group = RadioGroup()
	
	local menu = SimpleMenu("menu", {
		{
			text = self:string("NMPSMB"),
			style = 'item_choice',
			check = RadioButton(
				"radio", group,
					function(event, menuItem)
					self:getSettings()["nmp"] = "smb"
					self:storeSettings()
				end,
			nmp == "smb")
		},
		{
			text = self:string("NMPSMBUSER"),
			sound = "WINDOWSHOW",
			callback = function(event, menuItem)
				self:keyboardWindow(menuItem, 'qwerty', Textinput.textValue("", 0, 99), "nmpsmbuser")					
			end
		},
		{
			text = self:string("NMPSMBPASS"),
			sound = "WINDOWSHOW",
			callback = function(event, menuItem)
				self:keyboardWindow(menuItem, 'qwerty', Textinput.textValue("", 0, 99), "nmpsmbpass")					
			end
		},
		{
			text = self:string("NMPSMBCLEAR"),
			style = 'item_choice',
			sound = "WINDOWSHOW",
			callback = function(event, menuItem)
				self:getSettings()["nmpsmbuser"] = ""
				self:getSettings()["nmpsmbpass"] = ""
				self:storeSettings()
			end
		},
		{
			text = self:string("NMPSMBSAVE"),
			style = 'item_choice',
			sound = "WINDOWSHOW",
			callback = function(event, menuItem)
				self:storeSettings()
			end
		},
	})

	window:addWidget(menu)
	menu:setHeaderWidget(textarea)
	self:tieAndShowWindow(window)
	return window;
end


-- Define the LMS submenu
function installlms(self, menuItem)

	helpmsg = os.capture('sqp_JogglerFeatures.sh lms help')

	local window = Window("text_list", menuItem.text)
	local textarea = Textarea("help_text", helpmsg)
	
	local lms = self:getSettings()["lms"]

	local group = RadioGroup()
	
	local menu = SimpleMenu("menu", {
		{
			text = self:string("LMSINSTALL"),
			style = 'item_choice',
			check = RadioButton(
				"radio", group,
				function(event, menuItem, statusfile)
					self:popupscreen('LMSINSTALLING','REBOOTREQ')
					os.execute("sqp_JogglerFeatures.sh lms install &")
					self:getSettings()["lms"] = "enabled"
					self:storeSettings()
				end,
			lms == "enabled")
		},
		{
			text = self:string("LMSREMOVE"),
			style = 'item_choice',
			check = RadioButton(
				"radio", group,
				function(event, menuItem)
					self:popupscreen('LMSREMOVING','REBOOTREQ')		
					os.execute("sqp_JogglerFeatures.sh lms uninstall &")
					self:getSettings()["lms"] = "disabled"
					self:storeSettings()
				end,
			lms == "disabled")
		},
		{
			text = self:string("LMSRESTART"),
			style = 'item_choice',
			sound = "WINDOWSHOW",
			callback = function(event, menuItem)
				os.execute("sudo service logitechmediaserver restart")
				self:popupmsg('LMSRESTARTMSG',8000)
			end
		},
	})

	window:addWidget(menu)
	menu:setHeaderWidget(textarea)
	self:tieAndShowWindow(window)
	return window;
end


-- Define the SSH submenu
function installssh(self, menuItem)
	local window = Window("text_list", menuItem.text)
	local textarea = Textarea("help_text", self:string("SSHINFO"))
	
	local ssh = self:getSettings()["ssh"]

	local group = RadioGroup()
	
	local menu = SimpleMenu("menu", {	
		{
			text = self:string("SSHINSTALL"),
			style = 'item_choice',
			check = RadioButton(
				"radio", group,
				function(event, menuItem, statusfile)
					self:popupmsg('SSHINSTALLING',5000)
					os.execute("sqp_JogglerFeatures.sh ssh install &")
					self:getSettings()["ssh"] = "enabled"
					self:storeSettings()
				end,
			ssh == "enabled")
		},
		{
			text = self:string("SSHREMOVE"),
			style = 'item_choice',
			check = RadioButton(
				"radio", group,
				function(event, menuItem)
					self:popupscreen('SSHREMOVING','REBOOTREQ')		
					os.execute("sqp_JogglerFeatures.sh ssh uninstall &")
					self:getSettings()["ssh"] = "disabled"
					self:storeSettings()
				end,
			ssh == "disabled")
		},	
	})

	window:addWidget(menu)
	menu:setHeaderWidget(textarea)
	self:tieAndShowWindow(window)
	return window;
end


-- Generic Keyboard
function keyboardWindow(self, menuItem, style, vals, saveas)

	local window = Window("input", menuItem.text)

	local textinput = Textinput("textinput", vals,
		function(_, value)
		
			log:info("Share IP: ", value)

			window:playSound("WINDOWSHOW")
			window:hide(Window.transitionPushRight)
			self:getSettings()[saveas] = value

			return true
		end)
	
 	local backspace = Keyboard.backspace()
    local group = Group('keyboard_textinput', { textinput = textinput, backspace = backspace } )

    window:addWidget(group)
	window:addWidget(Keyboard('keyboard', style, textinput))
	window:focusWidget(group)

	self:tieAndShowWindow(window)
	return window
	
end


-- This should check an installation's status, but it doesn't work in the intended way.
--function checkinstatus()
--	log:info("Install Status: Checking...")
--	instatusfile = io.open('/tmp/sqp_installstatus', "r")
--	instatus = instatusfile:read()
--	instatusfile:close()
--	log:info("Install Status: " .. instatus)
--end


-- Allows output of shell scripts to be captured.
function os.capture(cmd)
  local f = io.popen(cmd, 'r')
  local s = f:read('*a')
  f:close()
  return s
end


-- This is a simple on-screen message.
function popupmsg(self, msg, time)

       log:info(self:string(msg))
 
       -- create a Popup object, using already established 'toast_popup_text' skin style
       local popupmessage = Popup('toast_popup_text')
 
       -- add message to popup
       local popupmessageMessage = Group("group", {
                       text = Textarea('toast_popup_textarea',self:string(msg)),
             })
       popupmessage:addWidget(popupmessageMessage)
 
       -- display the message for 4 seconds
       popupmessage:showBriefly(time, nil, Window.transitionPushPopupUp, Window.transitionPushPopupDown)		

end


-- This is a full screen message. Use self.popup:hide() to get rid.
function popupscreen(self, warning, subwarning)

	log:info(self:string(warning))

    self.popup = Popup("waiting_popup")

	-- prevent exiting from the spinny
	self.popup:setAllowScreensaver(false)
	self.popup:setAlwaysOnTop(true)
	self.popup:setAutoHide(false)
	self.popup:ignoreAllInputExcept()

    self.popup:addWidget(Icon("icon_connecting"))
    self.popup:addWidget(Label("text", self:string(warning)))
    self.popup:addWidget(Label("subtext", self:string(subwarning)))
    self:tieAndShowWindow(self.popup)

end



--[[

=head1 LICENSE

Created by Andy Davison
birdslikewires.co.uk

This work is licensed under a Creative Commons Attribution-ShareAlike 3.0 Unported License.

=cut
--]]

